;+
;
; PROJECT:  KAPPA
;
; 
;
; NAME:
;	ion2filename_k
;
; PURPOSE:
;	Ion names as character strings are converted to
;	provide their complete file name (with out suffix)
;
; CATEGORY:
;	
;	naming utility
;
; CALLING SEQUENCE:
;
;       ION2FILENAME_K,Kappa,Ion,K_name,Filename
;
;
; INPUTS:
;       Kappa: e.g. 2
;	Ion:   such as 'c_2'
;
;
; OUTPUTS:
;       K_name:    !data_pth/c/c_2/c_2_k2
;	Filename:  !xuvtop/c/c_2/c_2
;
;
; EXAMPLE:
;
;                     > ion2filename_k,2,'c_4d',k_name,filename
;                     > print,filename
;                     > !xuvtop/c/c_4d/c_4d
;
; MODIFICATION HISTORY:
;
; 	Written by:	Ken Dere
;
;	V.2,  September 1999:  added for use with Version 3
;
;       V.3, 21-May-2002, Giulio Del Zanna (GDZ) 
;                   generalized directory concatenation to work for
;                   Unix, Windows  and VMS. 
;
; VERSION     :   3, 21-May-2002 
;
;
;-
pro ion2filename_k,kappa,ion,k_name,filename
;
if n_params(0) lt 4 then begin
   print,'    use> ion2filename_k,kappa,ion,k_name,filename'
   print,'    use> ion2filename,2, "c_6",k_name,filename'
   print,'    giving k_name= !data_pth/c/c_6/c_6_k2 filename = !xuvtop/c/c_6/c_6 , for example'
   return
endif
;
;
name=strtrim(ion,2)
;
;
locname=strlowcase(name)
pos=strpos(locname,'_')
l=strlen(pos)
first=strmid(locname,0,pos)
last=strmid(locname,pos+1,l-pos-1)
;
if pos ge 0 then begin
;
;
   name=ion

dir=concat_dir(!data_pth, first)

filename=concat_dir(concat_dir(dir, name), name)

get_kappa_str,kappa,s_kap

k_name=filename+'_k'+s_kap

;
endif else print,' incorrect format for ion name (i.e., c_2) ',ion
;
return
end
