function k_tot_recomb,kappa,gname,te
;
;return total recombination rates for the ion with gname
;  
; CALLING SEQUENCE:
;	Result = K_TOTD_reCOMB( Kappa, Ion_Name, Temperature )
;
; INPUTS:
;       Kappa: value of kappa
;       Gname:  The name of the ion in CHIANTI format, e.g., 'fe_13'
;               for Fe XIII.
;       Temperature:  The temperature(s) in K at which the rates are
;                     required.   
;
; OUTPUTS:
;       The total recombination rate in cm^3 s^-1 at the specified
;       temperatures. If a problem occurs, then -1 is returned.
;  
; EXAMPLE:
;       IDL> logt=findgen(41)/10.+4.0
;       IDL> t=10.^t
;       IDL> kappa=2
;       IDL> rate=k_tot_recomb(kappa,'o_6',t)
;  
; ver. 1, E. DZ. Jan. 2021  


IF n_params() LT 3 THEN BEGIN
  print,'Use:  IDL> rate = k_tot_recomb( Kappa, Ion_Name, Temperature )'
  return,-1.
ENDIF

cela=fix(kappa+0.0001)
  if cela gt 9.5 then s_kap=string(fix(cela),format='(i2)') else s_kap=string(fix(cela),format='(i1)')
s_kap=string(fix(cela),format='(i02)')
cast=kappa-cela
  if cast gt 0.2 then begin
    s_kap2=string(cast*100+.1,format='(i02)')
    s_k=s_kap+'p'+s_kap2
  endif else begin
    s_k=s_kap
  endelse
 
  pp=strpos(gname,'_')
  elmt=strmid(gname,0,pp)
  totfile=!data_pth+elmt+'/'+gname+'/'+gname+'_k'+s_k+'.trparams'

  chck=file_search(totfile,count=countf)
    if countf eq 0 then return,-1.
     
  
  openr,lun,totfile,/get_lun
  readf,lun,n_n
  a=fltarr(2,n_n)
  readf,lun,a
  close,lun
  free_lun,lun

  tot=reform(a(1,*))
  tt=reform(a(0,*))

  trec=-1
    
  n_t=n_elements(te)    
    if n_t eq 1 then temp=[te] else temp=te
    if n_t lt 1 then return,trec

  ind0=where((temp lt tt(0)),count0)
  ind=where((temp ge tt(0)) and (temp le tt(n_n-1)),count)
  ind0=where(temp gt tt(n_n-1),count1)

  trec=fltarr(n_t)

    if count0 gt 0 then begin
      aa=poly_fit(alog(tt(0:1)),alog(tot(0:1)),1)
      trec(ind0)=exp( aa(0)+aa(1)*alog(temp(ind0)) )
    endif  

    if count gt 0 then trec(ind)=exp(spline(alog(tt(ind)),alog(tot(ind)),alog(te(ind))))

    if count1 gt 0 then begin
      aa=poly_fit(alog(tt(n_n-2:n_n-1)),alog(tot(n_n-2:n_n-1)),1)
      trec(ind1)=exp( aa(0)+aa(1)*alog(temp(ind1)) )
    endif
return,trec

end
