;+
; NAME:
;       READ_RRLVL_K
;
; PURPOSE:
;       Read the level-resolved RR rates.
;
; CALLING SEQUENCE:
;	Result = CH_SETUP_ION_k(kappa, Ion_path, status )
;
; NOTES:
;       The program reads a free-format .rrlvl file, similar to the
;       .reclvl files (which are fixed format). 
;       As in the case of the .reclvl files, only the first
;       temperature array is read. 
;
; INPUTS:
;	fname:  The path name for an ion in CHIANTI format
;
; OUTPUTS:
;       A structure with the tags:
;       rate          The rate 
;       temp          The temperature (K)
;       final_level   The number identifying the final level in the
;                         recombined ion.
;       initial_level The  number identifying the initial_level in the
;                     recombining ion.
;       ref           The reference.
;
;       STATUS
;
;       A flag to tel the calling program if the .rrlvl file was
;       available (either 0 or 1)
;
;   ver.1: for KAPPA .DZ. Fe. 2021
; 
;-

function read_rrlvl_k,kappa,fname, status

namerec=fname+'.rrlvl'

resultrec=findfile(namerec)
if  resultrec(0) eq '' then begin
    status= 0
    return, -1 
 endif else status=1

    datarec=strarr(10000)
    lgt=''

    openr,1,namerec
    readf,1,lgt

    ntransrec=fix(strmid(lgt,8,6))
    ntemp=fix(strmid(lgt,14,4))

    tt=strmid(lgt,18)
    temp=fltarr(ntemp)
      for i=0,ntemp-1 do temp(i)=float(strmid(tt,i*10,10))
        

    final_level=intarr(ntransrec)
    initial_level=intarr(ntransrec)

    rate=dblarr(ntransrec,ntemp)
    inter=dblarr(ntemp)

aa=0 & aai=0 & aa1=0
      for i=0,ntransrec-1 do begin
        readf,1,lgt 
        reads,lgt,aa,aa,aai,aa1,inter
        rate[i,*]=inter
        initial_level[i]=aai
        final_level[i]=aa1
  endfor
     
    refstring=strarr(500)
    nref=0
    readf,1,lgt 
    lgt=''   
    while strcompress(lgt,/remove_all) ne '-1' do begin 
        readf,1,lgt
        if strcompress(lgt,/remove_all) ne '-1' then begin 
            refstring(nref)=lgt
            nref=nref+1
        endif 
    endwhile  

    ref=refstring(0:nref-1)
    close,1
      
    close,1

out={rate:rate,temp:temp,$
    final_level:final_level, initial_level:initial_level,ref:ref}

return, out 


 end 
