pro read_transp,filename,splstr

; Project KAPPA
;  
; to read transition parameters for the collisional excitation and de-excitation
;
;  INPUT:  full file name (!data_pth+'fe/fe_10/fe_10.transp')
;
;  OUTPUT:  structure with tags
;               .lvl1   lower level index
;               .lvl2   upper level index
;               .t_type transition type
;               .gf     gf value
;               .de     Delta-E for transition (rydbergs)
;  
;_____________________________________________________________
;
;  v.1  E.DZ. 08-AUG-2019

  if file_exist(filename) eq 1 then begin

    num=29.
     
    openr,lun,filename,/get_lun
    zet=1
    ion=1
    s_ref=strarr(50)
    s1='-1'
    s2=s1

    readf,lun,num
    
    num=long(num)
    ar=fltarr(7,num)

    readf,lun,ar
  
    readf,lun,s2

      for n=0,49 do begin
         readf,lun,s2
           if strpos(s2,s1) ge 0 then goto, label1
         s_ref(n)=s2
      endfor
    label1:
    close,lun  
    free_lun,lun
    tref=reform(s_ref(0:n-1))

    lvl1=reform(fix(ar(2,*)+0.0001))
    lvl2=reform(fix(ar(3,*)+0.0001))
    t_type=reform(fix(ar(4,*)+0.0001))
    gf=reform(ar(5,*))
    de=reform(ar(6,*))

    str={ lvl1: 0, lvl2: 0, t_type: 0, gf: 0., de: 0.}
    trstr=replicate(str,n_elements(lvl1))
    trstr.lvl1 = lvl1
    trstr.lvl2 = lvl2
    trstr.t_type = t_type
    trstr.gf = gf
    trstr.de = de

;
; Create the various ion identifiers from the filename.
;
    
   basename=file_basename(filename)
   bits=str_sep(basename,'.')
   ion_name=bits[0]
   convertname,ion_name,ion_z,ion_n
   ion_z=fix(ion_z)
   zion2spectroscopic,ion_z,ion_n,ion_roman
   ion_roman=strcompress(ion_roman)
   bits=strsplit(ion_roman,' ',/extract)
   ion_latex='\ion{'+bits[0]+'}{'+strlowcase(bits[1])+'}'
   ion_latex_alt='\ion{'+bits[0]+'}{'+trim(ion_n)+'}'
;
; Create the info structure
;
    info={ion_name: ion_name, ion_z: ion_z, ion_n: ion_n, ion_roman: ion_roman, $
      ion_latex: ion_latex, ion_latex_alt: ion_latex_alt, $
      filename: filename, ntrans: num}
;
; Combine the info and data structures into the final output
; structure. 
;
    splstr={info: info, data: trstr}  
  endif else begin    
    splstr=0.
    print,'READ_TRPARAM - no file found '+filename
  endelse  

end
