pro ups_kappa_interp_str,kappa,filename,kname,te,str
  print,kappa
  print,filename
;
; interpolation/extrapolation and descale of upsilons and downsilons
;
;
;  INPUT:
;  kappa - parameter kappa
;  ion   - name of  ion, e.g. 'c_4'
;  te - temperature in K for calculation of upsilons/downsilons, can be an array 
;
;  OUTPUT:
;  str:
;  ups_e,ups_d - upsilons/downsilons for temperatures te
;  energy - energies of the transitions
;  
;  EXAMPLES:
;  
;  
;  ups_kappa_interp_str,2,!data_pth+'/fe/fe_10/fe_10',!data_pth+'/fe/fe_10/fe_10_k2',1.e+6,str

  read_transp, filename+'.transp', str

;read data
  read_kappa_ups,kname,data_e,data_d,tmp0,energy
    if tmp0(0) lt 15 then tmp=tmp0 else tmp=alog10(tmp0)
   kappa=double(kappa)
   nx=n_elements(te)
   te=double(te)
     if nx eq 1 then  begin
       tt=dblarr(1)
       tt(0)=te
     endif else begin
       tt=te
     endelse
   ny=n_elements(energy) 
   n_t=n_elements(tmp)
   ups_e=dblarr(nx,ny)
   ups_d=dblarr(nx,ny)
   log_t=alog10(tt)


   for i=long64(0),long64(ny)-long64(1) do begin
       indx=where(data_e(*,i) gt 0.,count)
         if count le 2 then goto,label
       ll=where((log_t ge tmp(indx(0))) and (log_t le tmp(indx(count-1))),count1)
         if count1 ge 1 then begin
           res=spline(tmp(indx),alog10(data_e(indx,i)),log_t(ll))  ;excitation
           ups_e(ll,i)=10.^res
           res=spline(tmp(indx),alog10(data_d(indx,i)),log_t(ll))  ;de-excitation
           ups_d(ll,i)=10.^res 
         endif 
       l_ind=where(log_t lt tmp(indx(0)),count2)
         if count2 gt 0 then begin
           pp=((data_e(indx(1),i))-(data_e(indx(0),i)))/(tmp(indx(1))-tmp(indx(0)))  ;excitation
           l_res=(data_e(indx(0),i))+pp*(log_t(l_ind)-tmp(indx(0)))
           ups_e(l_ind,i)=l_res>0.
           pp=((data_d(indx(1),i))-(data_d(indx(0),i)))/(tmp(indx(1))-tmp(indx(0)))  ;de-excitation
           u_res=(data_d(indx(0),i))+pp*(log_t(l_ind)-tmp(indx(0)))
           ups_d(l_ind,i)=u_res>0.
         endif
       u_ind=where(log_t gt tmp(indx(count-1)),count3)
         if count3 gt 0 then begin
           pp=((data_e(indx(count-1),i))-(data_e(indx(count-2),i)))/(tmp(indx(count-1))-tmp(indx(count-2)))  ;excitation
           l_res=(data_e(indx(count-1),i))+pp*(log_t(u_ind)-tmp(indx(count-1)))
           ups_e(u_ind,i)=l_res>0.
           pp=((data_d(indx(count-1),i))-(data_d(indx(count-2),i)))/(tmp(indx(count-1))-tmp(indx(count-2)))  ;de-excitation
           u_res=(data_d(indx(count-1),i))+pp*(log_t(u_ind)-tmp(indx(count-1)))
           ups_d(u_ind,i)=u_res>0.
         endif

         aa=double(energy(i)*1.57888d5/tt)/(kappa-1.5)
       ups_e(*,i)=ups_e(*,i)/(1.+aa)^kappa   ;scaling:  /(1.+aa)^kappa;   aa=a/(kappa-1.5);    a=double(energy*1.57888d5/temp)

       goto, koniec          
       label:
print,'ERROR: Wrong data files for ion '+ion+', kappa '+sk+' and transition '+strcompress(string(i),/remove_all)
       koniec:
      
     endfor

       str=add_tag(str,ups_e,'k_ups')
       str=add_tag(str,ups_d,'k_dwns')
       str=add_tag(str,tt,'temp_array')
       str=add_tag(str,kappa,'kappa')
     
end
