pro ups_mxw_interp_str,filename,te,str
print,filename
;
; interpolation/extrapolation and descale of upsilons and downsilons
;
;
;  INPUT:
;  ion   - filename of  ion with tits full path, e.g. !data_pth+'c/c_4/c_4'
;  te - temperature for calculation of upsilons/downsilons, can be an array 
;
;  OUTPUT:
;  str:
;  ups  - upsilons for temperatures te
;  str   - info
;        - data (lv1,lv2,t_type,gf,de)
;        - mxw_ups     (ups)
;        - temp_array  (te)
;  EXAMPLES:
;  
;  
;  ups_mxw_interp_str,!data_pth+'fe/fe_11/fe_11',1.e+6,ups,str

mxwname=filename+'_mxw.ups'
chck=file_search(mxwname,count=count4)
if count4 eq 1 then begin
   
    read_transp, filename+'.transp', strc

;read data
    read_mxw_ups,filename+'_mxw',data_e,tmp0,energy
      if tmp0(0) lt 15 then tmp=tmp0 else tmp=alog10(tmp0)
     nx=n_elements(te)
     te=double(te)
       if nx eq 1 then  begin
         tt=dblarr(1)
         tt(0)=te
       endif else begin
         tt=te
       endelse
     ny=n_elements(energy) 
     n_t=n_elements(tmp)
     ups_e=dblarr(nx,ny)
     log_t=alog10(tt)

       for i=long64(0),long64(ny)-long64(1) do begin
         indx=where(data_e(*,i) gt 0.,count)
           if count le 1 then goto,label
         ll=where((log_t ge tmp(indx(0))) and (log_t le tmp(indx(count-1))),count1)
           if count1 ge 1 then begin
             res=spline(tmp(indx),alog10(data_e(indx,i)),log_t(ll))  ;excitation
             ups_e(ll,i)=10.^res
           endif 
         l_ind=where(log_t lt tmp(indx(0)),count2)
           if count2 gt 0 then begin
             pp=(data_e(indx(1),i)-data_e(indx(0),i))/(tmp(indx(1))-tmp(indx(0)))  ;excitation
             l_res=(data_e(indx(0),i))+pp*(log_t(l_ind)-tmp(indx(0)))
             ups_e(l_ind,i)=l_res>0.
           endif
         u_ind=where(log_t gt tmp(indx(count-1)),count2)
           if count2 gt 0 then begin
             pp=(data_e(indx(count-1),i)-data_e(indx(count-2),i))/(tmp(indx(count-1))-tmp(indx(count-2)))  ;excitation
           l_res=(data_e(indx(count-1),i))+pp*(log_t(u_ind)-tmp(indx(count-1)))
           ups_e(u_ind,i)=l_res>0.
         endif
         
         goto, koniec          
         label:
;print,'ERROR: Wrong data files for ion '+ion+' and transition '+strcompress(string(i),/remove_all)
         koniec:
      
       endfor

     strc=add_tag(strc,ups_e,'mxw_ups')
     strc=add_tag(strc,tt,'temp_array')
     strc=add_tag(strc,1,'mxw')
     str=strc
  endif else begin  

     upsname=filename+'.scups'
     read_scups, upsname, spls

     l1=spls.data.lvl1
     l2=spls.data.lvl2
     
     nx=n_elements(te)
     te=double(te)
       if nx eq 1 then  begin
         tt=dblarr(1)
         tt(0)=te
       endif else begin
         tt=te
       endelse
     ny=n_elements(spls.data) 
     ups_e=dblarr(nx,ny)

      if tt(0) lt 15 then tt=10.^tt

     
       for i=0L,long64(ny)-1L do begin
             
; descale the scaled Upsilon at the temperature tt:
        
          descale_scups,tt,spls,i,ups 
          ups_e(*,i)=ups
       endfor


     d0str={ lvl1: 0, lvl2: 0, t_type: 0, gf: 0., de: 0.}
     dstr0=replicate(d0str,ny)
     dstr0.lvl1 = l1
     dstr0.lvl2 = l2
     dstr0.t_type = spls.data.t_type
     dstr0.gf = spls.data.gf
     dstr0.de = spls.data.de

     info=spls.info

     strc={info: info, data: dstr0}
       
     strc=add_tag(strc,ups_e,'mxw_ups')
     strc=add_tag(strc,tt,'temp_array')
     strc=add_tag(strc,1,'mxw')
       
  endelse

str=strc
       
end
